
/* amosdio.  
	Handle plain bit-wise IO on the DIO connector on the AMOS-3000
	There are 2 open-drain lines that may be used as inputs or outputs,
	and 2 input-only lines. One of these is set to hit the system with
	an SCI, this linkage can be optionally turned off here through ioctl(). 

	Read and write is one byte each:
Bit #: 7 6 5 4  3     2    1    0      -
Read:  0 1 0 0 GPI5 GPI4 GPIO3 GPIO2   - 
Write: X X X X  X     X  GPIO3 GPIO2   - 
Pin:   - - - -  3     2    7    8      - 

DE9 connector pin-out: 
	Pin 1: +3.3V
	Pin 2: GPI4
	Pin 3: GPI5
	Pin 4: GND
	Pin 5: NC
	Pin 6: +5V
	Pin 7: GPIO3
	Pin 8: GPIO2
	Pin 9: GND

Ideas further on: 
	i2c protocol on the two bidirectional lines, linking into
	the i2c stack using i2c-dev and so on.
	Support some kind of external shift-register action	
*/ 

#ifndef AMOSDIO_HINCLUDED 
#define AMOSDIO_HINCLUDED 1

#include <linux/ioctl.h>

/* Bit values for states, changes, and resets. */ 
#define AMOSDIO_GPIO2 0x1
#define AMOSDIO_GPIO3 0x2
#define AMOSDIO_GPI4 0x4
#define AMOSDIO_GPI5 0x8


#define AMOSDIO_MAGIC 61

#define AMOSDIO_IOCRESET _IO(AMOSDIO_MAGIC, 0) 
/* ioctl(fd, AMOSDIO_IOCRESET);  */ 

/* Turn the SMI to suspend on GPI5 off. */ 
#define AMOSDIO_IOCTGPI5SMIOFF _IO(AMOSDIO_MAGIC, 1) 
/* ioctl(fd, AMOSDIO_IOCTGPI5SMIOFF);  */ 

/* Turn the SMI to suspend on GPI5 on. */ 
#define AMOSDIO_IOCTGPI5SMION _IO(AMOSDIO_MAGIC, 2) 
/* ioctl(fd, AMOSDIO_IOCTGPI5SMION );  */ 

/* Return the change bits values */ 
#define AMOSDIO_IOCGCHANGES _IOR(AMOSDIO_MAGIC, 3, int) 
/* ioctl(fd, AMOSDIO_IOCGCHANGES, pattern );  */ 

/* Reset the change bit flags. */ 
#define AMOSDIO_IOCSRSTCHANGES _IOW(AMOSDIO_MAGIC, 4, int) 
/* ioctl(fd, AMOSDIO_IOCSRSTCHANGES, pattern );  */ 

/* Naming standard for ioctl opcodes:
	define AMOSDIO_IOxSOMETHING 

	the letter X is one of:

	Set trough a pointer
	Get reply by setting through a pointer
	Tell directly with the argument value
	Query response is on the return value
	eXchange G then S atomically
	sHift T and Q atomically
*/ 
#endif



